pub trait EarlyEofOk<I, T>{
// Required method
fn early_eof_ok(self) -> TerminateEarlyOnUnexpectedEof<I, T> ⓘ;
}Expand description
A trait to wrap an Iterator and terminate without error on UnexpectedEof
pub trait EarlyEofOk<I, T>{
// Required method
fn early_eof_ok(self) -> TerminateEarlyOnUnexpectedEof<I, T> ⓘ;
}A trait to wrap an Iterator and terminate without error on UnexpectedEof